@@ -1,17 +1,17 @@
 use crate::{Frame, Scene};
+use core::mem::replace;
 use nalgebra::RealField;
-use std::mem::replace;
 
 /// Clamp as user boundary conditions of [`Frame`].
 ///
 /// Implements [`Default`] and can be created with `Clamp::default()`.
 #[derive(Clone)]
-pub struct Clamp<N: RealField> {
+pub struct Clamp<N: Copy + RealField> {
 	/// Ensures user boundary conditions. Default is [`Self::zcp_collision()`].
 	ubc: fn(frame: Frame<N>, scene: &Scene<N>) -> Frame<N>,
 }
 
-impl<N: RealField> Default for Clamp<N> {
+impl<N: Copy + RealField> Default for Clamp<N> {
 	fn default() -> Self {
 		Self {
 			ubc: Self::zcp_collision,
@@ -19,7 +19,7 @@ impl<N: RealField> Default for Clamp<N> {
 	}
 }
 
-impl<N: RealField> Clamp<N> {
+impl<N: Copy + RealField> Clamp<N> {
 	/// Computes clamped [`Frame`] wrt to user boundary conditions.
 	pub fn compute(&mut self, frame: Frame<N>, scene: &Scene<N>) -> Frame<N> {
 		(self.ubc)(frame, scene)
